@@ -136,8 +136,8 @@ class VCloudSecurity:
         """
         context = self._persistence.load(context_id)
         if context is False:
-            message = f"Context id {context_id} not found"
-            self._log.error(message)
+            message = f"Context not found"
+            self._log.error(f"Ctx={context_id}: " + message)
             raise VCDExtensionSecurity(message,
                                        status_code=status_codes.codes.forbidden,
                                        request_id=context_id)
@@ -289,8 +289,8 @@ class VCloudSecurity:
         owner_name = pyvcloud_owner.get_name()
         if owner_name.lower() != "system" and tenant_id != owner_id:
             message = f"Entity {entity.get_type()} with id '{entity.get_id()}' does not belong to tenant "\
-                      f"'{owner_name}' in request id {context_id}"
-            cls._log.error(message)
+                      f"'{owner_name}'"
+            cls._log.error(f"Ctx={context_id}: " + message)
             raise VCDExtensionEntityDoesNotBelongToTenant(message, request_id=context_id,
                                                           status_code=status_codes.codes.bad_request)
         return owner_name
@@ -300,8 +300,8 @@ class VCloudSecurity:
         uri = 'https://' + cls._config['host'] + '/api/admin/user/' + user_id
         user_resource = cls._instance.__client.get_resource(uri)
         if user_resource is None:
-            message = f"User id {user_id} not found in request id {context_id}"
-            cls._log.error(message)
+            message = f"User id {user_id} not found"
+            cls._log.error(f"Ctx={context_id}: " + message)
             raise VCDExtensionNonExistentUser(message, request_id=context_id,
                                               status_code=status_codes.codes.unauthorized)
         else:
@@ -336,12 +336,13 @@ class CheckPermissions:
                 user, user_org_id, user_org_name, user_rights = vcd_security.get_context(context_id)
             else:
                 message = "Security context not present"
-                self._log.error(message)
+                self._log.error(f"Ctx=None: " + message)
                 raise VCDExtensionSecurity(message,
                                            status_code=status_codes.codes.forbidden,
                                            request_id='not present')
 
             # Function invocation if calling an __init__() method
+            result = None
             if function.__name__ == '__init__':
                 result = function(*args, **kwargs)
 
